package com.midwest.rfid;

import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;

import com.ibm.jsdt.support.SupportBase;
import com.ibm.jsdt.support.SupportHelper;

/**
 * Pre-deployment checker for MidWest Trucking application.
 *  
 *  Verifies that:
 *
 *  1. IBM WebSphere Application Community Edition 1.1.0.1 is installed.
 *  2. There is at least 1MB of space in the destination directory.  
 */
public class MidwestTruckingPDC extends SupportBase {

	private Properties wasceProperties = null;
	private File wascePropertiesFile = null;
	
	/**
	 * Return the constant SUCCESS or FAILURE to indicate if WASCE is 
	 * installed.
	 *
	 * @return SUCCESS or FAILURE 
	 */	
	private int execute() {
		
		SupportHelper helper = new SupportHelper();
		return (isWasceInstalled(helper) & isRequiredSpaceAvailable(helper)) ? SUCCESS : FAILURE;
	}
	
	/**
	 * Return a boolean to indicate whether WASCE is installed. 
	 * 
	 * @param myHelper
	 * @return
	 */
	private boolean isWasceInstalled(SupportHelper myHelper) {

		return (getWasceProperties(myHelper)!= null);
	}
	
	/**
	 * Return a Properties instance for the WASCE _version.properties file or
	 * null if the file does not exist.
	 * 
	 * @param myHelper
	 * @return an instance of Properties
	 */
	private Properties getWasceProperties(SupportHelper myHelper) {
		
		if (wasceProperties == null) {
			File myPropFile = getWascePropertiesFile(myHelper);
			if (myPropFile.exists()) {
				wasceProperties = new Properties();
				try {
					FileInputStream fis = new FileInputStream(myPropFile);
					wasceProperties.load(fis);
					fis.close();
			    }
				catch (Exception e) {
					myHelper.log(e.toString());
				}
			}
			else {
				myHelper.log(
					"IBM WebSphere Application Server Community Edition is not installed.  " + 
					"The installation for Mid-West Trucking Solutions cannot continue.");
			}
		}
		return wasceProperties;
	}
	
	/**
	 * Return a File instance for the WASCE _version.properties file.  Use the 
	 * value of the shared variable that matches the current operating system 
	 * to determine the path to WASCE HOME.  
	 * 
	 * @param myHelper
	 * @return instance of File
	 */
	private File getWascePropertiesFile(SupportHelper myHelper) {
		if (wascePropertiesFile == null) {
			String variableName = myHelper.isWindows() ? "windowsWasceHome" : "linuxWasceHome";  
			String wasceHome = myHelper.getIbmNsiPropValue(variableName);
			wascePropertiesFile = new File(wasceHome + "/_version.properties");			
		}
		return wascePropertiesFile;
	}

	/**
	 * Return a boolean to indicate if enough disk space is available. 
	 * 
	 * @param myHelper
	 * @return
	 */
	private boolean isRequiredSpaceAvailable(SupportHelper myHelper) {

		boolean isValid = false;
		
		String targetDirectory = myHelper.getIbmNsiPropValue("targetDirectory");
		setPath(targetDirectory);
		setSizeMegaBytes(1);
		if (!(isValid = myHelper.isEnoughTargetDirSpace(this))) {
			myHelper.log(
					"There is not enough disk space on " + targetDirectory + ".  " +
					"The installation for Mid-West Trucking Solutions cannot continue.");		
		}		
		return isValid;
	}	

	/**
	 * Perform a Pre-Deployment Check to see if prerequisites are met. If it is
	 * not abort installation of the MidWest Trucking Application.
	 * 
	 * @param args
	 */
	public static void main(String[] args) {

		MidwestTruckingPDC preDeploymentChecker = new MidwestTruckingPDC();
		System.exit(preDeploymentChecker.execute());
	}
}
